==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/pt_PT.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "A carregar pre-visualização...",
    "Saved" : "Guardado",
    "Admin" : "Administrador",
    "a safe home for all your data" : "Um local seguro para todos os seus dados",
    "The given name is too long" : "O nome atribuído é demasiado longo",
    "The given web address is too long" : "O endereço web atribuído é demasiado longo",
    "The given slogan is too long" : "O slogan atribuído é demasiado longo",
    "The given color is invalid" : "A cor atribuída é inválida",
    "There is no error, the file uploaded with success" : "Não ocorreu nenhum erro, o ficheiro foi carregado com sucesso",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
    "No file was uploaded" : "O ficheiro foi carregado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Failed to write file to disk." : "Falhou a escrever o ficheiro no disco.",
    "A PHP extension stopped the file upload." : "Uma extensão PHP parou o carregamento do ficheiro.",
    "No file uploaded" : "Nenhum ficheiro carregado",
    "Unsupported image type" : "Tipo de imagem não suportado",
    "You are already using a custom theme" : "Já está a usar um tema personalizado",
    "Theming" : "Temática",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "A tematização possibilita a fácil personalização da aparência da sua instância e clientes suportados. Isto será visível para todos os utilizadores",
    "Name" : "Nome",
    "Reset to default" : "Repor original",
    "Web address" : "Endereço Web",
    "Web address https://…" : "Endereço Web https::// ...",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logótipo",
    "Upload new logo" : "Carregar novo logótipo",
    "Login image" : "Imagem de Login",
    "Upload new login background" : "Carregar imagem de segundo plano de Login",
    "Remove background image" : "Remover imagem de segundo plano",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte para imagens SVG para gerar automaticamente favicons com base na cor e no logotipo carregado.",
    "reset to default" : "restaurar valor padrão",
    "The uploaded file was only partially uploaded" : "O ficheiro escolhido foi apenas parcialmente carregado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/theming/l10n/pt_PT.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "A carregar pre-visualização...",
    "Saved" : "Guardado",
    "Admin" : "Administrador",
    "a safe home for all your data" : "Um local seguro para todos os seus dados",
    "The given name is too long" : "O nome atribuído é demasiado longo",
    "The given web address is too long" : "O endereço web atribuído é demasiado longo",
    "The given slogan is too long" : "O slogan atribuído é demasiado longo",
    "The given color is invalid" : "A cor atribuída é inválida",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
    "No file was uploaded" : "O ficheiro foi carregado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "No file uploaded" : "Nenhum ficheiro carregado",
    "Unsupported image type" : "Tipo de imagem não suportado",
    "Theming" : "Temática",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "A tematização possibilita a fácil personalização da aparência da sua instância e clientes suportados. Isto será visível para todos os utilizadores",
    "Name" : "Nome",
    "Reset to default" : "Repor original",
    "Web link" : "Hiperligação da Web",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logótipo",
    "Upload new logo" : "Carregar novo logótipo",
    "Login image" : "Imagem de Login",
    "Upload new login background" : "Carregar imagem de segundo plano de Login",
    "Remove background image" : "Remover imagem de segundo plano",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte para imagens SVG para gerar automaticamente favicons com base na cor e no logotipo carregado.",
    "You are already using a custom theme" : "Já está a usar um tema personalizado",
    "reset to default" : "restaurar valor padrão",
    "Web address" : "Endereço Web",
    "Web address https://…" : "Endereço Web https::// ...",
    "There is no error, the file uploaded with success" : "Não ocorreu nenhum erro, o ficheiro foi carregado com sucesso",
    "The uploaded file was only partially uploaded" : "O ficheiro escolhido foi apenas parcialmente carregado",
    "Failed to write file to disk." : "Falhou a escrever o ficheiro no disco.",
    "A PHP extension stopped the file upload." : "Uma extensão PHP parou o carregamento do ficheiro."
},
"nplurals=2; plural=(n != 1);");
